package com.link.core.basic.mvc.aop;

import com.link.core.basic.interceptors.mybatis.annotation.LinkOauthConditionV1;
import com.link.core.basic.interceptors.mybatis.annotation.LinkOauthConditionV2;
import com.link.core.basic.interceptors.mybatis.enumeration.HighestOauthType;
import com.link.core.basic.interceptors.mybatis.handle.select.SecurityMenuParse;
import com.link.core.basic.model.BasicModel;
import com.link.core.basic.service.BasicServiceException;
import com.link.core.util.PropertyUtil;
import com.link.core.util.StringUtils;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;

@Aspect
public class LinkApiHighestOauthCheckAspect {
   private static final String QUERY_BY_EXAMPLE_PAGE = "queryByExamplePage";

   @Pointcut("execution(* com.link..controller..*.*(..))")
   private void processCtrllerPointcut() {
   }

   @Around("processCtrllerPointcut()")
   public Object doPointcut(ProceedingJoinPoint joinPoint) throws Throwable {
      MethodSignature methodSignature = (MethodSignature)joinPoint.getSignature();
      Method method = methodSignature.getMethod();
      LinkApiHighestOauth methodAnnotation = (LinkApiHighestOauth)method.getDeclaredAnnotation(LinkApiHighestOauth.class);
      boolean checkFlag = false;
      if ("queryByExamplePage".equals(method.getName())) {
         checkFlag = true;
      } else if (null != methodAnnotation) {
         checkFlag = true;
      }

      if (!checkFlag) {
         return joinPoint.proceed();
      } else {
         Object[] methodParams = joinPoint.getArgs();
         if (null != methodParams && methodParams.length >= 1) {
            for(int i = 0; i < methodParams.length; ++i) {
               Object param = methodParams[i];
               if (param instanceof BasicModel) {
                  HttpServletRequest request = null;

                  for(int j = 0; j < methodParams.length; ++j) {
                     if (HttpServletRequest.class.isAssignableFrom(methodParams[j].getClass())) {
                        request = (HttpServletRequest)methodParams[j];
                     }
                  }

                  LinkOauthConditionV2 linkOauthConditionV2 = (LinkOauthConditionV2)param.getClass().getDeclaredAnnotation(LinkOauthConditionV2.class);
                  LinkOauthConditionV1 linkOauthConditionV1 = (LinkOauthConditionV1)param.getClass().getDeclaredAnnotation(LinkOauthConditionV1.class);
                  HighestOauthType[] var10000 = new HighestOauthType[]{HighestOauthType.ALL};
                  HighestOauthType[] highestOauthTypes;
                  if (null != linkOauthConditionV2) {
                     highestOauthTypes = linkOauthConditionV2.value();
                  } else {
                     if (null == linkOauthConditionV1) {
                        continue;
                     }

                     highestOauthTypes = linkOauthConditionV1.value();
                  }

                  Map<String, Object> result = new HashMap();
                  String oauth = ((BasicModel)param).getOauth();
                  if (StringUtils.isBlank(oauth)) {
                     result.put("success", false);
                     result.put("result", "未传入安全性条件");
                     result.put("detailMessage", "未传入安全性条件");
                     result.put("code", 400);
                     return result;
                  }

                  try {
                     String openFlag = PropertyUtil.getProperty("openHighestOauthCheck", (Long)null);
                     SecurityMenuParse.handleHighestOauth(highestOauthTypes, oauth, openFlag, request, param);
                  } catch (BasicServiceException var16) {
                     BasicServiceException e = var16;
                     result.put("success", false);
                     result.put("result", e.getMessage());
                     result.put("detailMessage", e.getDetailMessage());
                     result.put("code", e.getCode());
                     return result;
                  }
               }
            }

            return joinPoint.proceed();
         } else {
            return joinPoint.proceed();
         }
      }
   }
}
